@@ -1,4 +1,6 @@
 import collections
+import sys
+import time
 
 import xmltodict
 from cloudmesh.common.Shell import Shell
@@ -6,11 +8,19 @@ from cloudmesh.common.Shell import Shell
 import pprint
 import os
 import yaml
+from signal import signal, SIGINT
+from cloudmesh.common.dotdict import dotdict
+from datetime import date
+
+from datetime import datetime
+
 
 
 class Gpu:
 
     def __init__(self):
+
+        self.running = True
         try:
             self._smi = dict(self.smi(output="json"))['nvidia_smi_log']['gpu']
             if not isinstance(self._smi, list):
@@ -18,6 +28,23 @@ class Gpu:
         except KeyError:
             raise RuntimeError("nvidia-smi not installed.")
 
+
+    def exit_handler(self, signal_received, frame):
+        """
+        Kube manager has a build in Benchmark framework. In case you
+        press CTRL-C, this handler asures that the benchmarks will be printed.
+
+        :param signal_received:
+        :type signal_received:
+        :param frame:
+        :type frame:
+        :return:
+        :rtype:
+        """
+        # Handle any cleanup here
+        print('SIGINT or CTRL-C detected. Exiting gracefully')
+        self.running = False
+
     @property
     def count(self):
         try:
@@ -198,5 +225,50 @@ class Gpu:
             result = None
         return result
 
+    def watch(self, logfile=None, delay=1):
+
+        try:
+            delay=int(delay)
+        except Exception as e:
+            delay = 1
+
+        signal(SIGINT, self.exit_handler)
+
+        stream = sys.stdout
+        if logfile is None:
+            stream = sys.stdout
+        else:
+            stream = open(logfile, "w")
+
+        print("# ####################################################################################")
+        print ("# time, gpu_util %, memory_util %, encoder_util %, decoder_util %, gpu_temp C, power_draw W")
+
+        while self.running:
+            try:
+                today = date.today()
+                now = datetime.now().time()  # time object
+                data = self.smi(output="json")
+
+                utilization = dotdict(data["nvidia_smi_log"]["gpu"]["utilization"])
+                temperature = dotdict(data["nvidia_smi_log"]["gpu"]["temperature"])
+                power = dotdict(data["nvidia_smi_log"]["gpu"]["power_readings"])
+
+                #
+                # have alternative format without spaces
+                #
+                result = \
+                    f"{today} {now}, " \
+                    f"{utilization.gpu_util[:-2]: >3}, " \
+                    f"{utilization.memory_util[:-2]: >3}, " \
+                    f"{utilization.encoder_util[:-2]: >3}, " \
+                    f"{utilization.decoder_util[:-2]: >3}, " \
+                    f"{temperature.gpu_temp[:-2]: >5}, " \
+                    f"{power.power_draw[:-2]: >8}"
+
+                print (result, file=stream)
+
+            except Exception as e:
+                print (e)
+
     def __str__(self):
         return pprint.pformat(self._smi, indent=2)
